@@ -41,14 +41,13 @@
 
 #define SERVICE_NAME "gdm-password"
 
-G_DEFINE_TYPE (GisSummaryPage, gis_summary_page, GIS_TYPE_PAGE);
-
-#define GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GIS_TYPE_SUMMARY_PAGE, GisSummaryPagePrivate))
-
 struct _GisSummaryPagePrivate {
   ActUser *user_account;
   const gchar *user_password;
 };
+typedef struct _GisSummaryPagePrivate GisSummaryPagePrivate;
+
+G_DEFINE_TYPE_WITH_PRIVATE (GisSummaryPage, gis_summary_page, GIS_TYPE_PAGE);
 
 #define OBJ(type,name) ((type)gtk_builder_get_object(GIS_PAGE(page)->builder,(name)))
 #define WID(name) OBJ(GtkWidget*,name)
@@ -128,7 +127,7 @@ on_secret_info_query (GdmUserVerifier *user_verifier,
                       const char      *question,
                       GisSummaryPage  *page)
 {
-  GisSummaryPagePrivate *priv = page->priv;
+  GisSummaryPagePrivate *priv = gis_summary_page_get_instance_private (page);
   gboolean should_send_password = priv->user_password != NULL;
 
   g_debug ("PAM module secret info query: %s\n", question);
@@ -177,7 +176,7 @@ add_uid_file (uid_t uid)
 static void
 log_user_in (GisSummaryPage *page)
 {
-  GisSummaryPagePrivate *priv = page->priv;
+  GisSummaryPagePrivate *priv = gis_summary_page_get_instance_private (page);
   GError *error = NULL;
   GdmGreeter *greeter;
   GdmUserVerifier *user_verifier;
@@ -262,17 +261,16 @@ done_cb (GtkButton *button, GisSummaryPage *page)
 }
 
 static void
-prepare_cb (GisAssistant   *assistant,
-            GisPage        *which_page,
-            GisSummaryPage *this_page)
+gis_summary_page_shown (GisPage *page)
 {
-  if (GIS_PAGE (which_page) == GIS_PAGE (this_page))
-    {
-      GisSummaryPagePrivate *priv = this_page->priv;
-      gis_driver_get_user_permissions (GIS_PAGE (this_page)->driver,
-                                       &priv->user_account,
-                                       &priv->user_password);
-    }
+  GisSummaryPage *summary = GIS_SUMMARY_PAGE (page);
+  GisSummaryPagePrivate *priv = gis_summary_page_get_instance_private (summary);
+
+  gis_driver_save_data (GIS_PAGE (page)->driver);
+
+  gis_driver_get_user_permissions (GIS_PAGE (page)->driver,
+                                   &priv->user_account,
+                                   &priv->user_password);
 }
 
 static GtkBuilder *
@@ -336,7 +334,6 @@ update_distro_name (GisSummaryPage *page)
 {
   char *buffer;
   char *name;
-  char *label;
 
   name = NULL;
 
@@ -346,27 +343,24 @@ update_distro_name (GisSummaryPage *page)
       g_free (buffer);
     }
 
-  if (!name)
-    name = g_strdup ("GNOME 3");
-
-  label = g_strdup_printf (_("_Start using %s"), name);
-  gtk_label_set_label (GTK_LABEL (WID ("summary-start-button-label")), label);
-  g_free (label);
-  g_free (name);
+  if (name)
+    {
+      gchar *label;
+      label = g_strdup_printf (_("_Start using %s"), name);
+      gtk_label_set_label (GTK_LABEL (WID ("summary-start-button-label")), label);
+      g_free (label);
+      g_free (name);
+    }
 }
 
 static void
 gis_summary_page_constructed (GObject *object)
 {
   GisSummaryPage *page = GIS_SUMMARY_PAGE (object);
-  GisAssistant *assistant = gis_driver_get_assistant (GIS_PAGE (page)->driver);
 
   G_OBJECT_CLASS (gis_summary_page_parent_class)->constructed (object);
 
   gtk_container_add (GTK_CONTAINER (page), WID ("summary-page"));
-
-  g_signal_connect_object (assistant, "prepare", G_CALLBACK (prepare_cb), page, 0);
-
   update_distro_name (page);
   g_signal_connect (WID("summary-start-button"), "clicked", G_CALLBACK (done_cb), page);
 
@@ -391,16 +385,14 @@ gis_summary_page_class_init (GisSummaryPageClass *klass)
   page_class->page_id = PAGE_ID;
   page_class->get_builder = gis_summary_page_get_builder;
   page_class->locale_changed = gis_summary_page_locale_changed;
+  page_class->shown = gis_summary_page_shown;
   object_class->constructed = gis_summary_page_constructed;
-
-  g_type_class_add_private (object_class, sizeof(GisSummaryPagePrivate));
 }
 
 static void
 gis_summary_page_init (GisSummaryPage *page)
 {
   g_resources_register (summary_get_resource ());
-  page->priv = GET_PRIVATE (page);
 }
 
 void
